Module: Thunderer::ViewHelpers
- Defined in:
- lib/thunderer/view_helpers.rb
Instance Method Summary collapse
-
#publish_to(channel, data = nil, &block) ⇒ Object
Publish the given data or block to the client by sending a Net::HTTP POST request to the Faye server.
-
#subscribe_to(channel) ⇒ Object
Subscribe the client to the given channel.
Instance Method Details
#publish_to(channel, data = nil, &block) ⇒ Object
Publish the given data or block to the client by sending a Net::HTTP POST request to the Faye server. If a block or string is passed in, it is evaluated as JavaScript on the client. Otherwise it will be converted to JSON for use in a JavaScript callback.
8 9 10 |
# File 'lib/thunderer/view_helpers.rb', line 8 def publish_to(channel, data = nil, &block) Thunderer.publish_to(channel, data || capture(&block)) end |
#subscribe_to(channel) ⇒ Object
Subscribe the client to the given channel. This generates some JavaScript calling PrivatePub.sign with the subscription options.
15 16 17 18 19 20 |
# File 'lib/thunderer/view_helpers.rb', line 15 def subscribe_to(channel) subscription = Thunderer.subscription(:channel => channel) content_tag 'script', :type => 'text/javascript' do raw("Thunderer.sign(#{subscription.to_json});") end end |